@@ -6,7 +6,7 @@ import re
 from .exceptions import ExecNameError, OperationExistsError, OptionExistsError, ArgumentValueError, GroupExistsError, \
     GroupNotExistsError, InvalidOptionError, InvalidOperationError
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 
 class Arguments:
@@ -374,23 +374,23 @@ class Arguments:
                     raise ArgumentValueError(f'invalid value type: "{self.operations[operation_title]["value_type"]}"')
             else:
                 print(f'Error: operation "{real_operation}" requires at least one argument')
-                sys.exit(1)
+                raise SystemExit(1)
         else:
 
             print('Error: only one operation at the same time is supported')
-            sys.exit(1)
+            raise SystemExit(1)
 
     def __match_option(self, option_title: str, real_option: str, real_argument: str) -> None:
 
         if self.active_operation is not None and self.options[option_title]['available_with_operations'] is not None \
                 and self.active_operation not in self.options[option_title]['available_with_operations']:
             print(f'Error: option "{real_option}" is not available with operation "{self.active_operation}"')
-            sys.exit(1)
+            raise SystemExit(1)
 
         elif self.active_operation is not None and self.options[option_title]['available_with_groups'] is not None \
                 and self.operations[self.active_operation]['group'] not in self.options[option_title]['available_with_groups']:
             print(f'Error: option "{real_option}" is not available with operation "{self.active_operation}"')
-            sys.exit(1)
+            raise SystemExit(1)
 
         else:
 
@@ -402,7 +402,7 @@ class Arguments:
                         self.output_options[option_title] = int(self.arguments[self.arguments.index(real_argument) + 1])
                     except ValueError:
                         print(f'Error: operation "{real_option}" requires an integer')
-                        sys.exit(1)
+                        raise SystemExit(1)
                     else:
                         self.arguments.pop(self.arguments.index(real_argument) + 1)
                 elif self.options[option_title]['value_type'] == str:
@@ -420,7 +420,7 @@ class Arguments:
                     raise ArgumentValueError(f'invalid value type: "{self.options[option_title]["value_type"]}"')
             else:
                 print(f'Error: option "{real_option}" requires at least one argument')
-                sys.exit(1)
+                raise SystemExit(1)
 
     def parse(self) -> [dict, dict]:
         """
@@ -491,7 +491,7 @@ class Arguments:
 
                     else:
                         print(f'Error: invalid argument "{character}" in "{argument}"')
-                        sys.exit(1)
+                        raise SystemExit(1)
 
             elif self.allow_short_args_together and len(argument) > 1 and argument[0:2] in self.short_options.keys():
 
@@ -508,11 +508,11 @@ class Arguments:
 
                     elif character in self.short_operations.keys() or f'-{character}' in self.short_operations.keys():
                         print('Error: operation must be specified before any other arguments')
-                        sys.exit(1)
+                        raise SystemExit(1)
 
                     else:
                         print(f'Error: invalid argument "{character}" in "{argument}"')
-                        sys.exit(1)
+                        raise SystemExit(1)
 
             elif self.isolate_unmatched and self.active_operation is not None and not re.match(r'-[A-z0-9_.\-]*', argument) \
                     and self.operations[self.active_operation]['value_type'] == list:
@@ -531,49 +531,49 @@ class Arguments:
                     self.output_operations[self.active_operation] = int(argument)
                 except ValueError:
                     print(f'Error: operation "{argument}" requires an integer')
-                    sys.exit(1)
+                    raise SystemExit(1)
 
             else:
 
                 print(f'Error: invalid argument "{argument}"')
-                sys.exit(1)
+                raise SystemExit(1)
 
         # Check if all active operations that require a list, a str or a int have at least one value
         for active_operation in self.output_operations.keys():
             if self.operations[active_operation]['value_type'] == list and self.output_operations[active_operation] == []:
                 print(f'Error: operation "{active_operation}" requires at least one argument')
-                sys.exit(1)
+                raise SystemExit(1)
             elif self.operations[active_operation]['value_type'] in (str, int) and self.output_operations[active_operation] is None:
                 print(f'Error: operation "{active_operation}" requires at least one argument')
-                sys.exit(1)
+                raise SystemExit(1)
 
         # Check if all required operations are active
         for operation in self.operations:
             if self.operations[operation]['required'] and operation not in self.output_operations.keys():
                 print(f'Error: operation "{operation}" is required')
-                sys.exit(1)
+                raise SystemExit(1)
 
         # Check if all required options (by an operation or by the program) are available
         for option in self.options:
             if self.options[option]['required'] and option not in self.output_options.keys():
                 print(f'Error: option "{option}" is required')
-                sys.exit(1)
+                raise SystemExit(1)
             if self.options[option]['required_by_operations'] is not None and option not in self.output_options:
                 for required in self.options[option]['required_by_operations']:
                     if required in self.output_operations.keys():
                         print(f'Error: operation "{required}" requires the option "{option}"')
-                        sys.exit(1)
+                        raise SystemExit(1)
             if self.options[option]['required_by_groups'] is not None and option not in self.output_options:
                 for required_group in self.options[option]['required_by_groups']:
                     for operation in self.operations:
                         if self.operations[operation]['group'] == required_group:
                             print(f'Error: operation "{operation}" requires the option "{option}"')
-                            sys.exit(1)
+                            raise SystemExit(1)
 
         # Check if at least one operation is specified
         if self.output_operations == {} and self.one_operation_required:
             print('Error: one operation is required')
-            exit(1)
+            raise SystemExit(1)
 
         # Set all the unused arguments to False or None
         for operation in self.operations:
